"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Emits log messages via an EventEmitter.
 * @internal
 */
class LogEmitter {
    constructor(emitter, debug) {
        this._emitter = emitter;
        this._debug = debug;
    }
    /**
     * Emits a log event with a message and possibly additional data.
     */
    log(message, data) {
        let logEventData = { ...data, message, level: "info" /* Info */ };
        this._emitter.emit("log" /* Log */, logEventData);
    }
    /**
     * Emits a log event, only if debug mode is enabled.
     */
    debug(message, data) {
        if (this._debug) {
            let logEventData = { ...data, message, level: "debug" /* Debug */ };
            this._emitter.emit("log" /* Log */, logEventData);
        }
    }
    /**
     * Emits a log event with a warning message and possibly additional data.
     */
    warn(warning, data) {
        let logEventData = { ...data, ...splitError(warning, this._debug), level: "warning" /* Warning */ };
        this._emitter.emit("log" /* Log */, logEventData);
    }
    /**
     * Emits a log event with an error message and possibly additional data.
     */
    error(error, data) {
        let logEventData = { ...data, ...splitError(error, this._debug), level: "error" /* Error */ };
        this._emitter.emit("log" /* Log */, logEventData);
    }
}
exports.LogEmitter = LogEmitter;
/**
 * Splits an Error or error message into two separate values.
 */
function splitError(arg, debug) {
    if (typeof arg === "string") {
        return { message: arg };
    }
    else {
        let error = arg;
        let message = arg.message || String(arg);
        if (debug) {
            message = arg.stack || message;
        }
        return { message, error };
    }
}
exports.splitError = splitError;
//# sourceMappingURL=log-emitter.js.map