"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Determines if the given value is a `ModuleDefinition` object,
 * or a string that's shorthand for `ModuleDefinition.moduleId`.
 * @internal
 */
function isModuleDefinition(value) {
    return typeof value === "string" || (value && typeof value.moduleId === "string");
}
exports.isModuleDefinition = isModuleDefinition;
/**
 * Determines if the given value is a `Plugin` object.
 * @internal
 */
function isPlugin(value) {
    let plugin = value;
    return Boolean(plugin &&
        typeof plugin === "object" &&
        (
        // A plugin must implement at least one method
        plugin.read || plugin.watch || plugin.clean || plugin.dispose ||
            plugin.processFile || plugin.processFiles)
        &&
            (plugin.read === undefined || typeof plugin.read === "function") &&
        (plugin.watch === undefined || typeof plugin.watch === "function") &&
        (plugin.clean === undefined || typeof plugin.clean === "function") &&
        (plugin.dispose === undefined || typeof plugin.dispose === "function") &&
        (plugin.processFiles === undefined || typeof plugin.processFiles === "function") &&
        (plugin.processFile === undefined ||
            typeof plugin.processFile === "function" ||
            isModuleDefinition(plugin.processFile)));
}
exports.isPlugin = isPlugin;
/**
 * Determines whether the given Plugin implements the `read()` method
 * @internal
 */
function isFileSource(plugin) {
    return !!plugin.read;
}
exports.isFileSource = isFileSource;
/**
 * Determines whether the given Plugin implements the `processFile()` and/or `processFiles()` methods.
 * @internal
 */
function isBuildStep(plugin) {
    return !!plugin.processFile || !!plugin.processFiles;
}
exports.isBuildStep = isBuildStep;
/**
 * Determines whether the given Plugin implements the `watch()` method
 * @internal
 */
function hasWatch(plugin) {
    return !!plugin.watch;
}
exports.hasWatch = hasWatch;
/**
 * Determines whether the given Plugin implements the `clean()` method
 * @internal
 */
function hasClean(plugin) {
    return !!plugin.clean;
}
exports.hasClean = hasClean;
/**
 * Determines whether the given Plugin implements the `dispose()` method
 * @internal
 */
function hasDispose(plugin) {
    return !!plugin.dispose;
}
exports.hasDispose = hasDispose;
//# sourceMappingURL=types.js.map